[Python-checkins] gh-90867: test.support.wait_process() uses LONG_TIMEOUT (#99071)

vstinner webhook-mailer at python.org
Fri Nov 4 09:41:38 EDT 2022


https://github.com/python/cpython/commit/f09da28768b77713566e932e912f107b6b57e8fd
commit: f09da28768b77713566e932e912f107b6b57e8fd
branch: main
author: Victor Stinner <vstinner at python.org>
committer: vstinner <vstinner at python.org>
date: 2022-11-04T14:41:33+01:00
summary:

gh-90867: test.support.wait_process() uses LONG_TIMEOUT (#99071)

The test.support.wait_process() function now uses a timeout of
LONG_TIMEOUT seconds by default, instead of SHORT_TIMEOUT.  It
doesn't matter if a Python buildbot is slower, it only matters that
the process completes. The timeout should just be shorter than
"forever".

files:
M Lib/test/support/__init__.py

diff --git a/Lib/test/support/__init__.py b/Lib/test/support/__init__.py
index 1dee708deb8c..a631bfc80cfa 100644
--- a/Lib/test/support/__init__.py
+++ b/Lib/test/support/__init__.py
@@ -2097,7 +2097,7 @@ def wait_process(pid, *, exitcode, timeout=None):
 
     Raise an AssertionError if the process exit code is not equal to exitcode.
 
     If the process runs longer than timeout seconds (SHORT_TIMEOUT by default),
     kill the process (if signal.SIGKILL is available) and raise an
     AssertionError. The timeout feature is not available on Windows.
     """
@@ -2105,7 +2105,7 @@ def wait_process(pid, *, exitcode, timeout=None):
         import signal
 
         if timeout is None:
-            timeout = SHORT_TIMEOUT
+            timeout = LONG_TIMEOUT
 
         start_time = time.monotonic()
         for _ in sleeping_retry(timeout, error=False):
@@ -2097,7 +2097,7 @@ def wait_process(pid, *, exitcode, timeout=None):
     Raise an AssertionError if the process exit code is not equal to exitcode.
 
-    If the process runs longer than timeout seconds (SHORT_TIMEOUT by default),
+    If the process runs longer than timeout seconds (LONG_TIMEOUT by default),
     kill the process (if signal.SIGKILL is available) and raise an
     AssertionError. The timeout feature is not available on Windows.



More information about the Python-checkins mailing list